var fanPower = "dimmer_1/Channel 1";
var fanSwitch = "dimmer_1/K1";
var humiditySensor = "DatVan/Humidity";
var motionSensor = "DatVan/Current Motion";
var sanuzelSwitch = "Switch_sanuzel/state_left";
var minFanPower = 50; // Минимальная мощность вентилятора (50%)
var maxFanPower = 100; // Максимальная мощность вентилятора (100%)
 
var manualFanActive = false;
var logEnabled = false; // Флаг, определяющий, включено ли логирование
var scriptName = "FanControl"; // Название вашего скрипта

// Создание виртуального устройства для управления вентилятором
// Создание виртуального устройства для управления вентилятором и логированием
defineVirtualDevice("fan_control", {
  title: "Управление Вентилятором",
  cells: {
    manualMode: {
      title: "Ручное управление",
      type: "switch",
      value: false,
      order: 1, // Установите порядок 1 для этой ячейки
    },
    manualPower: {
      title: "Мощность вентилятора",
      type: "range",
      max: 100,
      min: 0,
      value: 0,
      order: 2, 

    },
    logEnabled: {
      type: "switch",
      title: "Логирование",
      value: logEnabled,
      readonly: false,
      order: 3, // Установите порядок 3 для этой ячейки

    },
  },
});

defineRule("log_control", {
  whenChanged: "fan_control/logEnabled",
  then: function (newValue, devName, cellName) {
    logEnabled = newValue;
    log(scriptName + ": Логирование " + (logEnabled ? "включено" : "отключено") + " через управление виртуальным устройством.");
  },
});

// Функция логирования действий скриптов
function logAction(action) {
  if (logEnabled) {
    log(scriptName + ": " + action);
  }
} 

defineRule("fan_control", {
  whenChanged: ["fan_control/manualMode", "fan_control/manualPower", humiditySensor, motionSensor, sanuzelSwitch],
  then: function () {
    var humidity = dev[humiditySensor];
    var motion = dev[motionSensor];
    var sanuzelSwitchState = dev[sanuzelSwitch];
    var isDaytime = true; // Замените на логику определения времени суток
    var isWinter = false; // Замените на логику определения времени года

    // Логика управления вентилятором
    if (manualFanActive) {
      // Если активен ручной режим, применяем мощность в диапазоне от 50% до 100%
      var manualPower = dev["fan_control/manualPower"];
      var convertedPower = minFanPower + (maxFanPower - minFanPower) * (manualPower / 100);
      controlFan(convertedPower, true);
      logAction("Ручное управление вентилятором: Мощность установлена на " + convertedPower + "%");
    } else if (sanuzelSwitchState == "on") {
      // Если выключатель санузла включен, определяем мощность с учетом условий
      var power = calculateFanPower(humidity, isDaytime, isWinter);
      controlFan(power, true);
      logAction("Выключатель санузла включен: Вентилятор установлен на " + power + "% мощности");
    } else if (motion) {
      // Если обнаружено движение, определяем мощность при обнаружении движения
      var powerOnMotion = calculateFanPowerOnMotion();
      controlFan(powerOnMotion, true);
      logAction("Обнаружено движение: Вентилятор установлен на " + powerOnMotion + "% мощности");
    } else {
      // В остальных случаях вентилятор выключен
      controlFan(0, false);
      logAction("Вентилятор выключен");
    }
  },
});



// Функция для определения мощности вентилятора
function calculateFanPower(humidity, isDaytime, isWinter) {
  var power = 0;
  
  // Определение мощности вентилятора в зависимости от условий
  if (humidity > 70) {
    // Если влажность превышает 70%, установить максимальную мощность
    power = maxFanPower;
  } else if (!isDaytime && isWinter) {
    // В ночное время и в зимний период, установить мощность на 50%
    power = minFanPower + (maxFanPower - minFanPower) * 0.5;
  } else {
    // В остальных случаях установить мощность на 30%
    power = minFanPower + (maxFanPower - minFanPower) * 0.3;
  }
  
  return power;
}

// Функция для определения мощности вентилятора при обнаружении движения
function calculateFanPowerOnMotion() {
  // В данном случае, установим мощность на 60%
  return minFanPower + (maxFanPower - minFanPower) * 0.6;
}


// Функция для вычисления времени выключения вентилятора после выключения света
function calculateFanTurnOffDelay() {
  // В данном случае, установим задержку на 15 минут (900000 миллисекунд)
  return 900000;
}



// Функция управления вентилятором
// Функция управления вентилятором
function controlFan(power, state) {
  dev[fanSwitch] = state; // Включает или выключает вентилятор
  dev[fanPower] = power; // Устанавливает уровень мощности вентилятора
  //dev["fan_control"]["manualPower"] = power; // Обновляет значение manualPower в виртуальном устройстве
}


// Правило для ручного управления вентилятором
defineRule("manual_fan_control", {
  whenChanged: ["fan_control/manualMode", "fan_control/manualPower"],
  then: function () {
    if (dev["fan_control/manualMode"]) {
      logAction(
        "Ручной режим вентилятора активирован. Установка мощности на " +
          dev["fan_control/manualPower"] +
          "%."
      );
      controlFan(dev["fan_control/manualPower"], true);
      manualFanActive = true;
      startManualFanTimer(); // Запуск таймера для ручного режима
    } else {
      logAction("Ручной режим вентилятора деактивирован. Возвращение к автоматическому управлению.");
    }
  },
});

function startManualFanTimer() {
  if (!manualFanActive) return;
  setTimeout(function () {
    controlFan(0, false);
    manualFanActive = false;
    logAction("Ручной режим вентилятора: Вентилятор автоматически отключен после 6 часов работы.");
  }, 21600000); // 6 часов
}
