var hotWaterThreshold = 3.0; // Порог давления для горячей воды в барах
var pressureChangeThreshold = 1; // Порог изменения давления для срабатывания скрипта
var lastHotWaterPressure = dev["pressure_sensor"]["PressureHot"]; // Последнее измеренное давление горячей воды
var checkInterval = 30 * 60 * 1000; // Интервал проверки в миллисекундах (30 минут)
var totalChecks = 4; // Общее количество проверок
var currentChecks = 0; // Текущее количество выполненных проверок

defineRule("hot_water_control", {
  whenChanged: "pressure_sensor/PressureHot",
  then: function(newValue, devName, cellName) {
    var pressureDifference = Math.abs(newValue - lastHotWaterPressure);

    if (pressureDifference >= pressureChangeThreshold) {
      lastHotWaterPressure = newValue;
      log.info("Значительное изменение давления горячей воды: " + newValue + " бар");

      if (newValue < hotWaterThreshold && dev["pressure_sensor"]["PressureCold"] > hotWaterThreshold) {
        log.info("Давление горячей воды ниже порога. Включаем водонагреватель и управляем клапанами.");

        dev["relle_2_moshnoe"]["K2"] = true; // Включаем водонагреватель
        dev["voda_1"]["K2"] = false; // Закрываем клапан горячей воды
        dev["voda_2"]["K1"] = true; // Открываем клапан циркуляции 1
        dev["voda_2"]["K2"] = true; // Открываем клапан циркуляции 2

        currentChecks = 0;
        startRegularCheck();
      }
    }
  }
});

function startRegularCheck() {
  var timerId = setInterval(function() {
    log.info("Регулярная проверка давления горячей воды (" + (currentChecks + 1) + "/" + totalChecks + ")");

    if (++currentChecks >= totalChecks || dev["pressure_sensor"]["PressureHot"] >= hotWaterThreshold) {
      log.info("Остановка регулярной проверки. Возвращаем систему в исходное состояние.");

      clearInterval(timerId); // Остановка проверок
      dev["relle_2_moshnoe"]["K2"] = false; // Выключаем водонагреватель
      dev["voda_1"]["K2"] = true; // Открываем клапан горячей воды
      dev["voda_2"]["K1"] = false; // Закрываем клапан циркуляции 1
      dev["voda_2"]["K2"] = false; // Закрываем клапан циркуляции 2
    }
  }, checkInterval);
}
