// Виртуальное устройство для записи данных о погоде и отправки их в MQTT
defineVirtualDevice("weather", {
  title: "Погода в Екатеринбурге",
  cells: {
    temperature: {
      type: "temperature",
      value: 0.0,
      forceDefault: true,
      readonly: false
    },
    humidity: {
      type: "rel_humidity",
      value: 0.0
    },
    wind: {
      type: "wind_speed",
      value: 0.0
    },
    sunrise: {
      type: "value",
      value: 0.0
    },
    sunset: {
      type: "value",
      value: 0.0
    },
    manualUpdate: {
      type: "pushbutton",
      title: "Ручное обновление"
    }
  }
});

// Регулярный запрос данных о погоде
defineRule("weather_call", {
  when: cron("@every 1h"),
  then: function () {
    runShellCommand("wget -qO /usr/weather/data.json 'https://api.openweathermap.org/data/2.5/weather?id=1486209&appid=f7be926d415d577dc633f51db139b61c&units=metric'");
    startTimer("wait_weather", 5000); // Задержка 5 секунд
    log("Отправлен запрос данных о погоде");
  }
});

// Обработка данных о погоде
defineRule("parse_weather", {
  when: function () {
    return timers.wait_weather.firing;
  },
  then: function () {
    var weatherData = readConfig("/usr/weather/data.json");

    var timezoneOffset = new Date().getTimezoneOffset() * 60 * 1000;
    var ekaterinburgOffset = 5 * 60 * 60 * 1000;

    var currentTime = new Date((weatherData.dt * 1000) - timezoneOffset + ekaterinburgOffset);
    var sunriseTime = new Date((weatherData.sys.sunrise * 1000) - timezoneOffset + ekaterinburgOffset);
    var sunsetTime = new Date((weatherData.sys.sunset * 1000) - timezoneOffset + ekaterinburgOffset);

    dev["weather"]["temperature"] = weatherData.main.temp;
    dev["weather"]["humidity"] = weatherData.main.humidity;
    dev["weather"]["wind"] = weatherData.wind.speed;
    dev["weather"]["sunrise"] = sunriseTime.getTime();
    dev["weather"]["sunset"] = sunsetTime.getTime();

    log("Время: " + currentTime.toLocaleTimeString());
    log("Температура: " + weatherData.main.temp);
    log("Влажность: " + weatherData.main.humidity);
    log("Скорость ветра: " + weatherData.wind.speed);
    log("Восход солнца: " + sunriseTime.toLocaleTimeString());
    log("Закат солнца: " + sunsetTime.toLocaleTimeString());
  }
});

// Ручное обновление данных о погоде
defineRule("manual_weather_update", {
  whenChanged: "weather/manualUpdate",
  then: function () {
    runShellCommand("wget -qO /usr/weather/data.json 'https://api.openweathermap.org/data/2.5/weather?id=1486209&appid=f7be926d415d577dc633f51db139b61c&units=metric'");
    startTimer("wait_weather", 5000); // Задержка 5 секунд
    log("Ручное обновление данных о погоде запущено");
  }
});

// Управление реле в зависимости от температуры
defineRule("temperature_control", {
  whenChanged: "weather/temperature",
  then: function (newValue, devName, cellName) {
    if (newValue > -4) {
      dev["relle_4_switch"]["K2"] = true; // Включить реле
      log("Можно использовать кондиционер, так как температура выше -4°C.");
    } else {
      dev["relle_4_switch"]["K2"] = false; // Выключить реле
      log("Температура выше -4°C. Реле выключено.");
    }
  }
});

// Логирование обновления скрипта
log("Скрипт погоды обновлен!");
